# nohedidnt_py - NoHeDidn't Python-Library

[![PyPI](https://img.shields.io/pypi/v/nohedidnt_py)](https://pypi.org/project/nohedidnt-py/)
[![codecov](https://codecov.io/gh/NoHeDidnt/nohedidnt_py/branch/main/graph/badge.svg?token=U0OQI580BA)](https://codecov.io/gh/NoHeDidnt/nohedidnt_py)
[![Documentation Status](https://readthedocs.org/projects/nohedidnt-py/badge/?version=latest)](https://nohedidnt-py.readthedocs.io/en/latest/?badge=latest)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/nohedidnt_py)](https://pypi.org/project/nohedidnt-py/)
[![GitHub](https://img.shields.io/github/license/NoHeDidnt/nohedidnt_py)](./LICENSE)

This repo mainly serves two purposes: As an example for trying out some things on GitHub & as my collection of code I 
think I can use again in other projects.

## Links

### [Documentation](https://nohedidnt-py.readthedocs.io/en/latest/)
